.. _api_acse:

.. py:module:: pynetdicom.acse

ACSE Service (:mod:`pynetdicom.acse`)
======================================

The Association Control Service Element (ACSE) handles association-related tasks,
such as the processing of A-ASSOCIATE, A-RELEASE and
A-ABORT primitives in response to service requests made by the user or a
peer AE.

.. toctree::
   :maxdepth: 2
   :includehidden:

   acse.provider
